<?php

class DispletRetsIdxUsersApiController extends DispletRetsIdxApiController {
	public static function create_user( $email, $first_name, $last_name ) {
		$user_data = array(
			'email' => $email,
			'first_name' => $first_name,
			'last_name' => $last_name
		);
		$query_args = array(
			'user' => $user_data,
		 );
		$json_data = parent::query( '/users', $query_args );
		if ( !empty( $json_data->id ) ) {
			self::maybe_update_user( $json_data, $user_data );
			return $json_data->id;
		}
		return false;
	}

	private function maybe_update_user( $json_data, $user_data ) {
		if ( !empty( $json_data->updated_at ) ) {
			$yesterydays_epoch = strtotime( '-1 day' );
			$updated_epoch = strtotime( $json_data->updated_at );
			if ( $updated_epoch < $yesterydays_epoch ) {
				self::update_user( $json_data->id, $user_data );
			}
		}
	}

	public static function update_user( $api_user_id, $user_array ) {
		if ( !empty( $user_array ) ) {
			$query_args = array(
				'user' => $user_array
			 );
			$endpoint_url = '/users/' . $api_user_id;
			parent::query( $endpoint_url, $query_args, 'PUT' );
		}
	}

	public static function update_user_property_views( $api_user_id, $property_id ) {
		if ( !empty( $api_user_id ) && !empty( $property_id ) ) {
			$endpoint_url = '/users/' . $api_user_id . '/property_views';
			$query_args = array(
				'residential_id' => $property_id
			 );
			parent::query( $endpoint_url, $query_args );
		}
	}

	public static function create_saved_search( $user_id, $search_name, $search_criteria ) {
		$endpoint_url = '/users/' . $user_id . '/saved_searches';
		$query_args = array(
			'name' => $search_name,
			'search_criteria' => $search_criteria,
			'email_frequency' => 1
		 );
		$json_data = parent::query( $endpoint_url, $query_args );
		if ( !empty( $json_data->id ) ) {
			return $json_data->id;
		}
		return false;
	}

	public static function delete_saved_search( $user_id, $search_id ) {
		$endpoint_url = '/users/' . $user_id . '/saved_searches/' . $search_id;
		parent::query( $endpoint_url, false, 'DELETE' );
	}

	/* Not needed currently but used successfully during testing
	public static function get_user( $user_id ) {
		global $displetretsidx_option;
		$query_url = parent::$api_url . '/users/' . $user_id;
		$query_args = array(
			'timeout' => 10,
			'headers' => array(
				'referer' => home_url(  )
			 ),
			'body' => array(
				'authentication_token' => $displetretsidx_option['displet_app_key']
			 )
		 );
		$json_array = wp_remote_get( $query_url, $query_args );
		if ( is_array( $json_array ) ) {
			$json_data = json_decode( $json_array['body'] );
			return $json_data;
		}
	}

	public static function get_saved_searches( $user_id ) {
		global $displetretsidx_option;
		$query_url = parent::$api_url . '/users/' . $user_id . '/saved_searches';
		$query_args = array(
			'timeout' => 10,
			'headers' => array(
				'referer' => home_url(  )
			 ),
			'body' => array(
				'authentication_token' => $displetretsidx_option['displet_app_key']
			 )
		 );
		$json_array = wp_remote_get( $query_url, $query_args );
		if ( is_array( $json_array ) ) {
			$json_data = json_decode( $json_array['body'] );
			return $json_data;
		}
	}

	public static function get_saved_search( $user_id, $search_id ) {
		global $displetretsidx_option;
		$query_url = parent::$api_url . '/users/' . $user_id . '/saved_searches/' . $search_id;
		$query_args = array(
			'timeout' => 10,
			'headers' => array(
				'referer' => home_url(  )
			 ),
			'body' => array(
				'authentication_token' => $displetretsidx_option['displet_app_key']
			 )
		 );
		$json_array = wp_remote_get( $query_url, $query_args );
		if ( is_array( $json_array ) ) {
			$json_data = json_decode( $json_array['body'] );
			return $json_data;
		}
	}

	public static function update_saved_search( $user_id, $search_id, $search_criteria ) {
		global $displetretsidx_option;
		$query_url = parent::$api_url . '/users/' . $user_id . '/saved_searches/' . $search_id;
		$query_args = array(
			'method' => 'PUT',
			'timeout' => 10,
			'headers' => array(
				'referer' => home_url(  )
			 ),
			'body' => array(
				//'saved_search' => array(
					'search_criteria' => $search_criteria,
				// ),
				'authentication_token' => $displetretsidx_option['displet_app_key']
			 )
		 );
		$json_array = wp_remote_post( $query_url, $query_args );
		if ( is_array( $json_array ) ) {
			$json_data = json_decode( $json_array['body'] );
			return $json_data;
		}
	}
	*/
}

?>