<?php

/*
 * Plugin name: Displet RETS/IDX
 * Plugin URI: http://displet.com/wordpress-plugins/displetreader-wordpress-plugin
 * Description: RETS/IDX Plugin that inserts real estate listings, statistics, maps, and quick searches into Wordpress pages & widget ready sidebars. Free version available.
 * Version: 2.0.41
 * Author: Displet
 * Author URI: http://displet.com/
 * License: GPL2
 */

class DispletRetsIdxPlugin {
	protected static $plugin_version = '2.0.41';
	protected static $api_url = 'http://api.displet.com';
	protected static $settings_option = 'displet_rets_idx_options';
	protected static $version_option = 'displet_rets_idx_plugin';
	protected static $notify_option = 'displet_rets_idx_version';
	protected static $field_option = 'displet_rets_idx_field_options';
	protected static $action_option = 'displet_rets_idx_action_options';

	protected static $_capabilities = array(
		'save_property' => 'displet_save_properties',
		'save_search' => 'displet_save_searches',
		'view_leads' => 'displet_view_leads',
	);
	protected static $_file = __FILE__;
	protected static $_field_options;
	protected static $_options;
	protected static $_roles = array(
		'lead' => 'displet_user',
		'agent' => 'displet_agent',
	);
	protected static $_slug = 'displetreader-wordpress-plugin';
	protected static $_slugs = array(
		'lead_manager_page' => 'displet-lead-manager',
		'saved_properties_page' => 'displetretsidx_saved_properties',
		'saved_searches_page' => 'displetretsidx_saved_searches',
	);

	public static function include_version(){
		echo '<!-- Displet RETS/IDX v. ' . self::$plugin_version . ' -->';
	}

	public static function maybe_notify(){
		global $displetretsidx_option;
		$last_version = DispletRetsIdxSettingsController::get_option('notify');
		if (version_compare(self::$plugin_version, $last_version, '>')) {
			if (version_compare('2.0.12', $last_version, '>') && empty($displetretsidx_option['displet_app_token'])) {
				$model = array(
					'version' => '2.0.12',
					'message' => '<h3>Attention: Existing Displet Users</h3><p>Please take notice that we have recently upgraded our security procedures and have <b>added an API password</b> to your settings page. If you have already authenticated, <b>you do not need to enter a password</b>, but may wish to request the password for future use by <a href="http://displet.zendesk.com" target="_blank">submitting a ticket</a>.</p>'
				);
				echo DispletRetsIdxTemplatesController::get_admin_template('displet-notification-jquery.php', $model);
			}
			else if (version_compare('2.0.13', $last_version, '>')) {
				$model = array(
					'version' => '2.0.13',
					'message' => '<h3>New Displet Feature</h3><p>You can now view your users favorites & saved searches directly from your lead management screen. Click the details link next to each lead.</p>'
				);
				echo DispletRetsIdxTemplatesController::get_admin_template('displet-notification-jquery.php', $model);
			}
			else if (version_compare('2.0.25', $last_version, '>')) {
				$model = array(
					'version' => '2.0.25',
					'message' => '<h3>New Displet Feature</h3><p>We\'ve given the login/regisration prompt a facelift and new options! Take a look on your RE Search Settings page to find the newly added <b>"soft prompt"</b> and <b>"back prompt"</b> options, which offer more flexibility on how you\'d like to encourage registration. Soft prompts can be closed, and back prompts return you to the previous page.</p>'
				);
				echo DispletRetsIdxTemplatesController::get_admin_template('displet-notification-jquery.php', $model);
			}
			else {
				DispletRetsIdxSettingsController::update_option('notify', self::$plugin_version);
			}
		}
	}

	public static function maybe_deactivate(){
		$active_plugins = get_option('active_plugins');
		if (!empty($active_plugins) && is_array($active_plugins)) {
			$plugins = array();
			$alert = false;
			foreach ($active_plugins as $plugin) {
				if ($plugin == 'displetsearch-wordpress-plugin/DispletReader.php') {
					$alert = true;
				}
				if ($plugin != 'displetreader-wordpress-plugin/displetreader-wordpress-plugin.php') {
					$plugins[] = $plugin;
				}
			}
			if ($alert) {
				update_option('displetretsidx_deactivated', true);
				wp_schedule_single_event(time(), 'displetretsidx_update_active_plugins', array($plugins));
			}
		}
	}

	public static function maybe_notify_of_deactivation(){
		$deactivated = get_option('displetretsidx_deactivated');
		if (!empty($deactivated)) {
			echo '<div class="error"><h3>Warning! Displet RETS/IDX Deactivated</h3><p>Displet RETS/IDX was deactivated because it appears DispletReader Legacy is currently active. If you wish to use Displet RETS/IDX, please first deactivate DispletReader Legacy.</p></div>';
			update_option('displetretsidx_deactivated', false);
		}
	}

	public static function update_active_plugins($plugins){
		update_option('active_plugins', $plugins);
	}
}

add_action('wp_head', array('DispletRetsIdxPlugin', 'include_version'), 1000000);
add_action('admin_head', array('DispletRetsIdxPlugin', 'maybe_notify'));
add_action('displetretsidx_update_active_plugins', array('DispletRetsIdxPlugin', 'update_active_plugins'));
add_action('admin_notices', array('DispletRetsIdxPlugin', 'maybe_notify_of_deactivation'));
register_activation_hook(__FILE__, array('DispletRetsIdxPlugin', 'maybe_deactivate'));
register_activation_hook(__FILE__, array('DispletRetsIdxSettingsController', 'register_default_settings'));
register_activation_hook(__FILE__, array('DispletRetsIdxSearchFieldWidgetController', 'register_default_widgets'));
register_activation_hook(__FILE__, array('DispletRetsIdxSearchFieldWidgetController', 'register_default_widget_areas_content'));
register_activation_hook(__FILE__, array('DispletRetsIdxRewriteController', 'reset_flush_rewrite_rules'));
register_activation_hook(__FILE__, array('DispletRetsIdxEmailController', 'adjust_activity_report_schedule'));
register_deactivation_hook(__FILE__, array('DispletRetsIdxEmailController', 'unschedule_activity_report'));

require_once('displet-requires.php');
require_once('displet-admin-requires.php');

?>